@@ -1,6 +1,6 @@
 <?php
 /**
- * $Horde: imp/compose.php,v 2.369.2.55 2003/02/19 00:02:30 jan Exp $
+ * $Horde: imp/compose.php,v 2.369.2.56 2003/03/08 01:15:32 slusarz Exp $
  *
  * Copyright 1999-2003 Charles J. Hagenbuch <chuck@horde.org>
  * Copyright 1999-2003 Jon Parise <jon@horde.org>
@@ -503,6 +503,9 @@ switch ($actionID) {
          $structure = @imap_fetchstructure($imp['stream'], $index, FT_UID);
          $attachments = MIME_Structure::parse($structure, $index, $MimeID);
          $msg = "\n" . findBody($attachments);
+	 if ($GLOBALS['language'] == 'ja_JP') {
+	     $msg = mb_convert_encoding($msg, mb_internal_encoding(), 'auto');
+	 }
          if (@count($structure->parts) > 1) {
              attachFiles($structure, '');
          }
@@ -596,6 +599,9 @@ switch ($actionID) {
                  $wrap_width = 20;
              }
              $msg = Text::wrap($msg, $wrap_width, $quote_str, Lang::getCharset());
+	     if ($GLOBALS['language'] == 'ja_JP') {
+		 $msg = mb_convert_encoding($msg, mb_internal_encoding(), 'auto');
+	     }
              $msg  = _("Quoting") . ' ' . $qfrom . ":\n$quote_str$msg";
              $msg .= "\n";
          }
@@ -657,7 +663,11 @@ switch ($actionID) {
          $structure = imap_fetchstructure($imp['stream'], $index, FT_UID);
          $attachments = MIME_Structure::parse($structure, $index, $MimeID);
          $msg .= "\n";
-	 $msg .= findBody($attachments);
+	 if ($GLOBALS['language'] == 'ja_JP') {
+	     $msg .= mb_convert_encoding(findBody($attachments), mb_internal_encoding(), 'auto');
+	 } else {
+	     $msg .= findBody($attachments);
+	 }
          $msg .= "\n----- " . _("End forwarded message") . " -----\n";
 
          if (isset($h->subject)) {
@@ -1225,6 +1235,7 @@ $timeout = ini_get('session.gc_maxlifetime');
 if (isset($actionID) && ($actionID == BOUNCE_COMPOSE)) {
     $mailbox = Horde::getFormData('thismailbox', $imp['mailbox']);
     include IMP_TEMPLATES . '/compose/bounce.inc';
+    include IMP_TEMPLATES . '/compose/javascript.inc';
 } else {
     if ($browser->hasFeature('javascript')) {
         include IMP_TEMPLATES . '/compose/javascript.inc';
