@@ -1,6 +1,6 @@
 <?php
 /**
- * $Horde: imp/mailbox.php,v 2.296.2.53 2003/02/12 11:10:29 jan Exp $
+ * $Horde: imp/mailbox.php,v 2.296.2.55 2003/03/11 03:28:27 slusarz Exp $
  *
  * Copyright 1999-2003 Charles J. Hagenbuch <chuck@horde.org>
  * Copyright 1999-2003 Jon Parise <jon@horde.org>
@@ -96,6 +96,8 @@ $actionID = Horde::getFormData('actionID');
 
 IMP::checkAuthentication();
 
+$newmail_popup = (Horde::getFormData('newmail_popup') == 'no') ? false : true;
+
 if (($actionID == IMP_LOGIN) || ($actionID == LOGIN_COMPOSE)) {
     if (isset($new_lang)) {
         $language = $new_lang;
@@ -111,6 +113,8 @@ if (($actionID == IMP_LOGIN) || ($actionID == LOGIN_COMPOSE)) {
             exit;
         }
     }
+
+    $newmail_popup = false;
 }
 
 /* Get form data and make sure it's the type that we're expecting. */
@@ -359,14 +363,14 @@ if ($imp['mailbox'] == '**search') {
     if ($prefs->getValue('delhide')) {
         $msgs = imap_search($imp['stream'], 'UNDELETED');
         $imp['msgcount'] = ($msgs !== false) ? count($msgs) : 0;
-        if ($prefs->getValue('nav_popup') && Horde::getFormData('newmail_popup') != 'no') {
+        if ($prefs->getValue('nav_popup') && $newmail_popup) {
             $new = imap_search($imp['stream'], 'RECENT UNDELETED');
             $newmsgs = $new ? count($new) : 0;
         }
     } else {
         $check = imap_check($imp['stream']);
         $imp['msgcount'] = (is_object($check) && isset($check->Nmsgs)) ? $check->Nmsgs : 0;
-        if ($prefs->getValue('nav_popup') && Horde::getFormData('newmail_popup') != 'no') {
+        if ($prefs->getValue('nav_popup') && $newmail_popup) {
             $new = imap_search($imp['stream'], 'RECENT');
             $newmsgs = $new ? count($new) : 0;
         }
@@ -611,7 +615,7 @@ ksort($mailboxOverview);
 // Display message information.
 $curr_time = time();
 $curr_time -= ($curr_time % 60);
-foreach ($mailboxOverview as $message) {
+foreach ($mailboxOverview as $key => $message) {
     if ($imp['mailbox'] == '**search') {
         if (!isset($lastFolder) || ($message['folder'] != $lastFolder)) {
             include IMP_TEMPLATES . '/mailbox/searchfolder.inc';
@@ -813,6 +817,9 @@ foreach ($mailboxOverview as $message) {
         }
         $from_link = Horde::link($from_uri, $frm) . $stylefrm . '</a>';
     } elseif ($conf['mailbox']['from_link'] == 'compose') {
+        if ($imp['mailbox'] == '**search') {
+            $array_index = $key;
+        }
         $compose_url = IMP::composeLink(array(), array('actionID' => MAILTO, 'mailbox' => $imp['mailbox'], 'index' => $h->uid));
         $from_link = Horde::link($compose_url, sprintf(_("Compose Message (%s)"), $frm)) . $stylefrm . '</a>';
     } else {
@@ -838,7 +845,7 @@ $navform = 2;
 require IMP_TEMPLATES . '/mailbox/navbar.inc';
 require IMP_TEMPLATES . '/mailbox/footer.inc';
 
-if ($prefs->getValue('nav_popup') && ($newmsgs > 0) && (Horde::getFormData('newmail_popup') != 'no')) {
+if ($newmail_popup && $prefs->getValue('nav_popup') && ($newmsgs > 0)) {
     include IMP_TEMPLATES . '/mailbox/alert.inc';
 }
 
